=====
poets
=====

This is the documentation of **poets**, a package with aims to provide a 
standard library that can be used for collecting and resampling geospatial 
image datasets.

Contents
========

.. toctree::
   :maxdepth: 3

   introduction.rst
   examples.rst

   License <license>
   Module Reference <_rst/modules>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
